==> hermes-3.0.0.12.tar.gz: hermes-3.0.0.12/spec/libs/bo_client/tasks/add_offer_task_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'
require 'vcr_config'

# exemple d'utilisation ho = Hermes::HousingOffer.find("5e4d3e2022ec796ac122cc4a")
#
# l1 = Hermes::Lessor.create(title: 'MON ENTREPRISE', siren: 'plop')
# a1 = Hermes::Entity.create(title: 'MON AGENCE', siren: 'replop', lessor: l1)
# ho = Hermes::HousingOffer.create(lessor: l1,rent_amount: 1264.23,rental_charges: 56.73, agency_id: a1.id, als_siren:"123456789",mad_als_date: Date.current, availability_date: Date.current,designation_date_end: Date.current,  )
#
#
=begin
ho = Hermes::HousingOffer.find("5e566e9022ec7958264a5981")
so = Hermes::BoClient::AddOfferTask.new({:'housing_offer_id' => ho.id})
so.to_xml
ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end
# exemple d'utilisation ho = Hermes::HousingOffer.find("5def769722ec791f58770f6e")



dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'FluxPatrimoine.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::AddOfferTask, type: :helper do
  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_offer' do
    let!(:lessor1) do
      create(:lessor,
             title: 'MON ENTREPRISE',
             siren: '123456789',
             siret: '12345678900000',
             )
    end
    THRESHOLD_MAP = {
      'Paris et alentours' => {
        'thresholds_list' => %w[
          12673
          14679
        ],
        'another_person' => '6723'
      }
    }.freeze
    let!(:responsible) { create(:user, roles: ['Administrator']) }
    let!(:threshold2) { create(:threshold, user_id: responsible.id.to_s, thresholds_map: THRESHOLD_MAP, type: 'PLA LM', codes: ['PLM']) }
    let!(:agency1) { create(:entity, title: 'MON AGENCE', siren: '123456789', lessor: lessor1) }
    let!(:housing_offer1) do
      create(
        :housing_offer,
        lessor: lessor1,
        rent_with_charges: 1264.23 + 56.73,
        rent_amount: 1264.23,
        rental_charges: 56.73,
        agency_id: agency1.id,
        als_siren: '123456789',
        is_mad_updated_at: Date.current,
        availability_date: Date.current,
        designation_date_end: Date.current,
        has_gardian: false,
        threshold_type: 'PLM',
        lessor_orientation: 'A',
        external_ref: 'truc',
        description: 'TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT',
        address: 'fzefqezfzef',
        address_complements: 'zeqfqzef',
        communicate_exact_address: true,
        postal_code: '30100',
        district: 'Alès',
        virtual_visit: true,
        furnished_lodging: false,
        terraces_or_balconies: 2,
        already_inhabited: false,
        residence_code: 'bibi',
        residence_title: 'la charmille',
        rpls_id: "1234567890",
        qpv: true,
        construction_type: 'T2',
        kind: '1',
        typology: 'A',
        country: "france",
        latitude: 2.22222222222222222222222,
        longitude: 3.33333333333333333333333,
        reserving_siren:"576435789",
      coordinates: [1, 2]
      )
    end
    let!(:picture0) { create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id) }
    let!(:picture1) { create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id) }

    let!(:add_offer_task1) do
      build(
        :add_offer_task,
        options: { housing_offer_id: housing_offer1.id }
      )
    end

    describe 'using to_xml' do
      it 'should return a valid xml' do
        add_offer_task1.validate_xml
        expect(housing_offer1.reload.last_xml_validation_report).to eq('[]')
        expect(xsd.validate(Nokogiri::XML(add_offer_task1.to_xml)).length).to eq(0)

        add_offer_task1.execute
        VCR.use_cassette("flux5", :match_requests_on => [:method, :uri, :path]) do
          drain_all_jobs
        end

        expect(housing_offer1.reload.last_send_has_error).to eq(true)
      end
    end
  end
end

==> hermes-5.4.0.1.tar.gz: hermes-5.4.0.1/spec/libs/bo_client/tasks/add_offer_task_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'
require 'vcr_config'

# exemple d'utilisation ho = Hermes::HousingOffer.find("5e4d3e2022ec796ac122cc4a")
#
# l1 = Hermes::Lessor.create(title: 'MON ENTREPRISE', siren: 'plop')
# a1 = Hermes::Entity.create(title: 'MON AGENCE', siren: 'replop', lessor: l1)
# ho = Hermes::HousingOffer.create(lessor: l1,rent_amount: 1264.23,rental_charges: 56.73, agency_id: a1.id, als_siren:"123456789",mad_als_date: Date.current, availability_date: Date.current,designation_date_end: Date.current,  )
#
#
=begin
ho = Hermes::HousingOffer.find("5e566e9022ec7958264a5981")
so = Hermes::BoClient::AddOfferTask.new({:'housing_offer_id' => ho.id})
so.to_xml
ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)
=end
# exemple d'utilisation ho = Hermes::HousingOffer.find("5def769722ec791f58770f6e")



dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'FluxPatrimoine.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::AddOfferTask, type: :helper do
  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_offer' do
    let!(:lessor1) do
      create(:lessor,
             title: 'MON ENTREPRISE',
             siren: '123456789',
             siret: '12345678900000',
             )
    end
    THRESHOLD_MAP = {
      'Paris et alentours' => {
        'thresholds_list' => %w[
          12673
          14679
        ],
        'another_person' => '6723'
      }
    }.freeze
    let!(:responsible) { create(:user, roles: ['Administrator']) }
    let!(:threshold2) { create(:threshold, user_id: responsible.id.to_s, thresholds_map: THRESHOLD_MAP, type: 'PLA LM', codes: ['PLM']) }
    let!(:agency1) { create(:entity, title: 'MON AGENCE', siren: '123456789', lessor: lessor1) }
    let!(:housing_offer1) do
      create(
        :housing_offer,
        lessor: lessor1,
        rent_with_charges: 1264.23 + 56.73,
        rent_amount: 1264.23,
        rental_charges: 56.73,
        agency_id: agency1.id,
        als_siren: '123456789',
        is_mad_updated_at: Date.current,
        availability_date: Date.current,
        designation_date_end: Date.current,
        has_gardian: false,
        threshold_type: 'PLM',
        external_ref: 'truc',
        description: 'TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT',
        address: 'fzefqezfzef',
        address_complements: 'zeqfqzef',
        communicate_exact_address: true,
        postal_code: '30100',
        district: 'Alès',
        virtual_visit: true,
        furnished_lodging: false,
        terraces_or_balconies: 2,
        already_inhabited: false,
        residence_code: 'bibi',
        residence_title: 'la charmille',
        rpls_id: "1234567890",
        qpv: true,
        construction_type: 'T2',
        kind: '1',
        typology: 'A',
        country: "france",
        latitude: 2.22222222222222222222222,
        longitude: 3.33333333333333333333333,
        reserving_siren:"576435789",
        coordinates: [1, 2],
        reference_mad: 'blabla',
        lessor_orientations: ['PDALO', 'PPAAC']
      )
    end
    let!(:picture0) { create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id) }
    let!(:picture1) { create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id) }

    let!(:add_offer_task1) do
      build(
        :add_offer_task,
        options: { housing_offer_id: housing_offer1.id }
      )
    end

    describe 'using to_xml' do
      it 'should return a valid xml' do
        add_offer_task1.validate_xml
        expect(housing_offer1.reload.last_xml_validation_report).to eq('[]')
        expect(xsd.validate(Nokogiri::XML(add_offer_task1.to_xml)).length).to eq(0)

        add_offer_task1.execute
        VCR.use_cassette("flux5", :match_requests_on => [:method, :uri, :path]) do
          drain_all_jobs
        end

        expect(housing_offer1.reload.last_send_has_error).to eq(true)
      end
    end

    describe 'check xml' do 
      it 'reference_mad and lessor_orientations' do 
        so = Hermes::BoClient::AddOfferTask.new({:'housing_offer_id'=> housing_offer1.id})
        xml = so.to_xml
        parsed_xml = Hash.from_xml(xml.gsub("\n", ""))
        expect(parsed_xml['patrimoine']['bien']['reference_MAD']).to eq(housing_offer1.reference_mad)
        expect(parsed_xml['patrimoine']['bien']['orientations_bailleur']['orientation']).to eq(housing_offer1.lessor_orientations)
      end 
    end 
  end
end
